==> designer-common-1.0.10-20251121.023748-1-sources.jar: com/digiwin/athena/constant/CompileDetailTypeConstant.java <==
package com.digiwin.athena.constant;

public class CompileDetailTypeConstant {
    /**
     * 数据侦测
     */
    public static final String MONITOR = "monitorRule";

    /**
     * 服务编排
     */
    public static final String AD_TEMPLATE = "adTemplate";

    /**
     * 项目
     */
    public static final String PROJECT = "project";

    /**
     * 任务
     */
    public static final String TASK = "task";

    /**
     * 数据转换关系
     */
    public static final String TASK_ACTIVITY = "task_activity";

    /**
     * 数据
     */
    public static final String DATA_DESCRIPTION = "dataDescription";

    /**
     * 行动
     */
    public static final String ACTION = "action";

    /**
     * 数据录入
     */
    public static final String DATA_ENTRY = "DataEntry";

    /**
     * 报表
     */
    public static final String STATEMENT = "Statement";

    /**
     * 机制
     */
    public static final String MECHANISM = "mechanism";

    /**
     * 拓展信息，前台放在"其他"类别下
     */
    public static final String EXTEND = "extend";

    /**
     * 参数设定，前台放在"机制"类别下
     */
    public static final String VARIABLE_DEFINITION = "variableDefinition";

    public static final String FLOW_GRAPH = "flowGraph";

    /**
     * 模型驱动的模型部分
     */
    public static final String MODEL_DRIVEN = "modelDriven";

    /**
     * 套件作业
     */
    public static final String KIT_ASSIGN = "kitAssign";

    /**
     * 数据视图
     */
    public static final String DATA_VIEW = "dataView";

    /**
     * 流程
     */
    public static final String PROCESS = "process";

    /**
     * 事件
     */
    public static final String EVENT = "event";

    /**
     * 定制插件
     */
    public static final String APP_CUSTOM_CONFIG = "applicationCustomConfig";

    /**
     * 数据流
     */
    public static final String DATA_FLOW = "dataFlow";

    /**
     * 移动端设计器
     */
    public static final String MOBILE_PAGE_DESIGN = "mobilePageDesign";

    public static final String OPEN_WINDOW_DEFINE = "openWindowDefinition";
    /**
     * 场景
     */
    public static final String SCENE = "scene";

    /**
     * 子页面
     */
    public static final String SUB_PAGE = "subPage";
}

==> designer-common-1.0.10-20251204.093924-24-sources.jar: com/digiwin/athena/constant/CompileDetailTypeConstant.java <==
package com.digiwin.athena.constant;

public class CompileDetailTypeConstant {
    /**
     * 数据侦测
     */
    public static final String MONITOR = "monitorRule";

    /**
     * 服务编排
     */
    public static final String AD_TEMPLATE = "adTemplate";

    /**
     * 项目
     */
    public static final String PROJECT = "project";

    /**
     * 任务
     */
    public static final String TASK = "task";

    /**
     * 数据转换关系
     */
    public static final String TASK_ACTIVITY = "task_activity";

    /**
     * 数据
     */
    public static final String DATA_DESCRIPTION = "dataDescription";

    /**
     * 行动
     */
    public static final String ACTION = "action";

    /**
     * 数据录入
     */
    public static final String DATA_ENTRY = "DataEntry";

    /**
     * 报表
     */
    public static final String STATEMENT = "Statement";

    /**
     * 机制
     */
    public static final String MECHANISM = "mechanism";

    /**
     * 拓展信息，前台放在"其他"类别下
     */
    public static final String EXTEND = "extend";

    /**
     * 参数设定，前台放在"机制"类别下
     */
    public static final String VARIABLE_DEFINITION = "variableDefinition";

    public static final String FLOW_GRAPH = "flowGraph";

    /**
     * 模型驱动的模型部分
     */
    public static final String MODEL_DRIVEN = "modelDriven";

    /**
     * 套件作业
     */
    public static final String KIT_ASSIGN = "kitAssign";

    /**
     * 数据视图
     */
    public static final String DATA_VIEW = "dataView";

    /**
     * 流程
     */
    public static final String PROCESS = "process";

    /**
     * 事件
     */
    public static final String EVENT = "event";

    /**
     * 定制插件
     */
    public static final String APP_CUSTOM_CONFIG = "applicationCustomConfig";

    /**
     * 数据流
     */
    public static final String DATA_FLOW = "dataFlow";

    /**
     * 移动端设计器
     */
    public static final String MOBILE_PAGE_DESIGN = "mobilePageDesign";

    public static final String OPEN_WINDOW_DEFINE = "openWindowDefinition";
    /**
     * 场景
     */
    public static final String SCENE = "scene";

    /**
     * 子页面
     */
    public static final String SUB_PAGE = "subPage";

    public static final String WORKBENCH_PORTAL = "WorkBenchPortal";


    /**
     * 数据
     */
    public static final String DATA_STATE = "dataState";
    /**
     * 参数设计器
     */
    public static final String APP_PARAM = "appParam";

}
